#!/bin/sh
#
#  this script builds libfwbuilder and libfwbuilder-devel RPMs
#
#

function die {
   echo $1
   exit 1
}

CONFIGURE_ARGS=$*

RPMROOT=/var/tmp/libfwbuilder
EXPORTDIR=`pwd`/export

export CCACHE_DIR=$HOME/.ccache

mkdir -p ${EXPORTDIR}

./autogen.sh --prefix=/usr ${CONFIGURE_ARGS} || exit 1

DISTRO=`cat /etc/issue|grep release|sed 's/Linux.*$//; s/ //g'`

SPECFILE=libfwbuilder.spec
MAJOR_LIB_NUM=`awk '/%define major/ { print $3; }' $SPECFILE`
if [ "x$MAJOR_LIB_NUM" == "x\'\'" ]; then
MAJOR_LIB_NUM=""
fi

PACKAGE_NAME="libfwbuilder${MAJOR_LIB_NUM}"


VERSION=`awk '/Version:/ { print $2; }' $SPECFILE`
TAR_FILE=${PACKAGE_NAME}-${VERSION}.tar.gz
SNAPSHOT_DIR=${PACKAGE_NAME}-${VERSION}

./maketar.sh "${PACKAGE_NAME}" "$VERSION"


echo " === Building libfwbuilder RPM version $VERSION === "

mkdir -p ${RPMROOT}
mkdir -p ${RPMROOT}/SOURCES
mkdir -p ${RPMROOT}/BUILD
mkdir -p ${RPMROOT}/SPECS
mkdir -p ${RPMROOT}/SRCS
mkdir -p ${RPMROOT}/RPMS
mkdir -p ${RPMROOT}/SRPMS

if [ ! -d $EXPORTDIR ]; then
    echo "Can't find export directory"
    exit 1
else

    cp ${EXPORTDIR}/${TAR_FILE} ${RPMROOT}/SOURCES
    cp ${SPECFILE} ${RPMROOT}/SPECS 
    cd ${RPMROOT}/SPECS

    DISTRO=`cat /etc/issue|grep release|sed 's/Linux.*$//; s/ //g'`
    if test "x${DISTRO}" == "xMandrake"; then
    	ARCH=`uname -m`
    	if [ "X$ARCH" = "Xi686" ]; then
		RPMARCH="--target i586"
    	fi
    fi

    rm -f .rpmmacros
    echo "%_topdir ${RPMROOT}" > .rpmmacros

    export HOME=`pwd`; rpmbuild -ba $RPMARCH ${SPECFILE} 
fi

